@@ -250,9 +250,34 @@ private:
 ARItem::ARItem(QListViewItem *item, const CommandDef *d)
         : ConfigItem(item, 0)
 {
+    string icon;
+
     m_status = d->id;
     setText(0, i18n(d->text));
-    setPixmap(0, Pict(d->icon, listView()->colorGroup().base()));
+    switch (d->id){
+    case STATUS_ONLINE: 
+        icon="SIM_online";
+        break;
+    case STATUS_AWAY:
+        icon="SIM_away";
+        break;
+    case STATUS_NA:
+        icon="SIM_na";
+        break;
+    case STATUS_DND:
+        icon="SIM_dnd";
+        break;
+    case STATUS_FFC:
+        icon="SIM_ffc";
+        break;
+    case STATUS_OFFLINE:
+        icon="SIM_offline";
+        break;
+    default:
+        icon=d->icon;
+        break;
+    }
+    setPixmap(0, Pict(icon.c_str(), listView()->colorGroup().base()));
 }
 
 QWidget *ARItem::getWidget(ConfigureDialog *dlg)
