@@ -42,7 +42,6 @@ class SearchDialog;
 class CommonStatus;
 class StatusWnd;
 class ConnectionManager;
-class Icons;
 
 typedef struct CoreData
 {
@@ -101,10 +100,14 @@ typedef struct CoreData
     Data	InvisibleStyle;
     Data	SmallGroupFont;
     Data	ShowAllEncodings;
-    Data	DefaultEncoding;
     Data	ShowEmptyGroup;
     Data	NoJoinAlert;
     Data	EnableSpell;
+    Data	RemoveHistory;
+    Data	SearchGeo[5];
+    Data	SearchClient;
+    Data	NoScroller;
+    Data	cfgGeo[5];
 } CoreData;
 
 const unsigned CONTAINER_SIMPLE	= 0;
@@ -174,156 +177,155 @@ public:
     void addToContacts();
 };
 
-typedef struct ENCODING
-{
-    const char *language;
-    const char *codec;
-    int         mib;
-    int		rtf_code;
-    int		cp_code;
-    bool        bMain;
-} ENCODING;
+const unsigned long CmdBase					= 0x00020000;
+const unsigned long CmdInfo					= (CmdBase + 1);
+const unsigned long CmdSearch				= (CmdBase + 2);
+const unsigned long CmdConnections			= (CmdBase + 3);
+const unsigned long CmdCM					= (CmdBase + 4);
+const unsigned long CmdChange				= (CmdBase + 5);
+const unsigned long CmdShowPanel			= (CmdBase + 6);
+const unsigned long CmdCommonStatus			= (CmdBase + 7);
+const unsigned long CmdTitle				= (CmdBase + 8);
+const unsigned long CmdSetup				= (CmdBase + 9);
+const unsigned long CmdMainWindow			= (CmdBase + 11);
+const unsigned long CmdUserView				= (CmdBase + 12);
+const unsigned long CmdContainer			= (CmdBase + 13);
+const unsigned long CmdClose				= (CmdBase + 14);
+const unsigned long CmdContainerContact		= (CmdBase + 15);
+const unsigned long CmdContainerContacts	= (CmdBase + 16);
+const unsigned long CmdSendMessage			= (CmdBase + 17);
+const unsigned long CmdSend					= (CmdBase + 18);
+const unsigned long CmdStatusMenu			= (CmdBase + 20);
+const unsigned long CmdStatusBar			= (CmdBase + 21);
+const unsigned long CmdQuit					= (CmdBase + 23);
+const unsigned long CmdMenu					= (CmdBase + 23);
+const unsigned long CmdOnline				= (CmdBase + 24);
+const unsigned long CmdGroup				= (CmdBase + 25);
+const unsigned long CmdGrpOff				= (CmdBase + 26);
+const unsigned long CmdGrpMode1				= (CmdBase + 27);
+const unsigned long CmdGrpMode2				= (CmdBase + 28);
+const unsigned long CmdGrpCreate			= (CmdBase + 29);
+const unsigned long CmdGrpRename			= (CmdBase + 30);
+const unsigned long CmdGrpDelete			= (CmdBase + 31);
+const unsigned long CmdGrpTitle				= (CmdBase + 32);
+const unsigned long CmdGrpUp				= (CmdBase + 33);
+const unsigned long CmdGrpDown				= (CmdBase + 34);
+const unsigned long CmdContactTitle			= (CmdBase + 35);
+const unsigned long CmdContactRename		= (CmdBase + 36);
+const unsigned long CmdContactDelete		= (CmdBase + 37);
+const unsigned long CmdConfigure			= (CmdBase + 38);
+const unsigned long CmdMessageType			= (CmdBase + 39);
+const unsigned long CmdSendClose			= (CmdBase + 40);
+const unsigned long CmdSmile				= (CmdBase + 41);
+const unsigned long CmdMultiply				= (CmdBase + 42);
+const unsigned long CmdSendSMS				= (CmdBase + 43);
+const unsigned long CmdInvisible			= (CmdBase + 44);
+const unsigned long CmdHistory				= (CmdBase + 45);
+const unsigned long CmdHistorySave			= (CmdBase + 46);
+const unsigned long CmdHistoryDirection		= (CmdBase + 47);
+const unsigned long CmdHistoryNext			= (CmdBase + 48);
+const unsigned long CmdHistoryPrev			= (CmdBase + 49);
+const unsigned long CmdMsgOpen				= (CmdBase + 51);
+const unsigned long CmdMsgQuote				= (CmdBase + 53);
+const unsigned long CmdMsgAnswer			= (CmdBase + 54);
+const unsigned long CmdMsgForward			= (CmdBase + 55);
+const unsigned long CmdCopy					= (CmdBase + 56);
+const unsigned long CmdCut					= (CmdBase + 57);
+const unsigned long CmdPaste				= (CmdBase + 58);
+const unsigned long CmdSelectAll			= (CmdBase + 59);
+const unsigned long CmdUndo					= (CmdBase + 60);
+const unsigned long CmdRedo					= (CmdBase + 61);
+const unsigned long CmdClear				= (CmdBase + 62);
+const unsigned long CmdSeparate				= (CmdBase + 63);
+const unsigned long CmdNextMessage			= (CmdBase + 65);
+const unsigned long CmdGrantAuth			= (CmdBase + 66);
+const unsigned long CmdRefuseAuth			= (CmdBase + 67);
+const unsigned long CmdPhones				= (CmdBase + 71);
+const unsigned long CmdLocation				= (CmdBase + 72);
+const unsigned long CmdPhoneState			= (CmdBase + 73);
+const unsigned long CmdPhoneNoShow			= (CmdBase + 74);
+const unsigned long CmdPhoneAvailable		= (CmdBase + 75);
+const unsigned long CmdPhoneBusy			= (CmdBase + 76);
+const unsigned long CmdPhoneBook			= (CmdBase + 77);
+const unsigned long CmdShowAlways			= (CmdBase + 78);
+const unsigned long CmdFileAccept			= (CmdBase + 79);
+const unsigned long CmdFileDecline			= (CmdBase + 80);
+const unsigned long CmdDeclineWithoutReason	= (CmdBase + 81);
+const unsigned long CmdDeclineReasonInput	= (CmdBase + 82);
+const unsigned long CmdDeclineReasonBusy	= (CmdBase + 83);
+const unsigned long CmdDeclineReasonLater	= (CmdBase + 84);
+const unsigned long CmdHistoryFind			= (CmdBase + 85);
+const unsigned long CmdFileName				= (CmdBase + 86);
+const unsigned long CmdPhoneNumber			= (CmdBase + 87);
+const unsigned long CmdTranslit				= (CmdBase + 88);
+const unsigned long CmdUrlInput				= (CmdBase + 89);
+const unsigned long CmdCutHistory			= (CmdBase + 90);
+const unsigned long CmdDeleteMessage		= (CmdBase + 91);
+const unsigned long CmdEditList				= (CmdBase + 92);
+const unsigned long CmdRemoveList			= (CmdBase + 93);
+const unsigned long CmdStatusWnd			= (CmdBase + 94);
+const unsigned long CmdEmptyGroup			= (CmdBase + 95);
+const unsigned long CmdEnableSpell			= (CmdBase + 96);
+const unsigned long CmdSpell				= (CmdBase + 97);
+const unsigned long CmdChangeEncoding		= (CmdBase + 98);
+const unsigned long CmdAllEncodings			= (CmdBase + 99);
+const unsigned long CmdSearchInfo			= (CmdBase + 101);
+const unsigned long CmdSearchMsg			= (CmdBase + 102);
+const unsigned long CmdSearchOptions		= (CmdBase + 103);
 
-const unsigned  CmdBase					= 0x00020000;
-const unsigned	CmdInfo					= (CmdBase + 1);
-const unsigned	CmdSearch				= (CmdBase + 2);
-const unsigned	CmdConnections			= (CmdBase + 3);
-const unsigned	CmdCM					= (CmdBase + 4);
-const unsigned	CmdChange				= (CmdBase + 5);
-const unsigned	CmdShowPanel			= (CmdBase + 6);
-const unsigned	CmdCommonStatus			= (CmdBase + 7);
-const unsigned	CmdTitle				= (CmdBase + 8);
-const unsigned	CmdSetup				= (CmdBase + 9);
-const unsigned	CmdMainWindow			= (CmdBase + 11);
-const unsigned	CmdUserView				= (CmdBase + 12);
-const unsigned	CmdContainer			= (CmdBase + 13);
-const unsigned	CmdClose				= (CmdBase + 14);
-const unsigned	CmdContainerContact		= (CmdBase + 15);
-const unsigned	CmdContainerContacts	= (CmdBase + 16);
-const unsigned	CmdSendMessage			= (CmdBase + 17);
-const unsigned	CmdSend					= (CmdBase + 18);
-const unsigned	CmdStatusMenu			= (CmdBase + 20);
-const unsigned	CmdStatusBar			= (CmdBase + 21);
-const unsigned	CmdQuit					= (CmdBase + 23);
-const unsigned	CmdMenu					= (CmdBase + 23);
-const unsigned	CmdOnline				= (CmdBase + 24);
-const unsigned	CmdGroup				= (CmdBase + 25);
-const unsigned	CmdGrpOff				= (CmdBase + 26);
-const unsigned	CmdGrpMode1				= (CmdBase + 27);
-const unsigned	CmdGrpMode2				= (CmdBase + 28);
-const unsigned	CmdGrpCreate			= (CmdBase + 29);
-const unsigned	CmdGrpRename			= (CmdBase + 30);
-const unsigned	CmdGrpDelete			= (CmdBase + 31);
-const unsigned	CmdGrpTitle				= (CmdBase + 32);
-const unsigned	CmdGrpUp				= (CmdBase + 33);
-const unsigned	CmdGrpDown				= (CmdBase + 34);
-const unsigned	CmdContactTitle			= (CmdBase + 35);
-const unsigned	CmdContactRename		= (CmdBase + 36);
-const unsigned	CmdContactDelete		= (CmdBase + 37);
-const unsigned  CmdConfigure			= (CmdBase + 38);
-const unsigned	CmdMessageType			= (CmdBase + 39);
-const unsigned	CmdSendClose			= (CmdBase + 40);
-const unsigned	CmdSmile				= (CmdBase + 41);
-const unsigned	CmdMultiply				= (CmdBase + 42);
-const unsigned  CmdSendSMS				= (CmdBase + 43);
-const unsigned	CmdInvisible			= (CmdBase + 44);
-const unsigned	CmdHistory				= (CmdBase + 45);
-const unsigned	CmdHistorySave			= (CmdBase + 46);
-const unsigned	CmdHistoryDirection		= (CmdBase + 47);
-const unsigned	CmdHistoryNext			= (CmdBase + 48);
-const unsigned	CmdHistoryPrev			= (CmdBase + 49);
-const unsigned	CmdMsgOpen				= (CmdBase + 51);
-const unsigned	CmdMsgQuote				= (CmdBase + 53);
-const unsigned	CmdMsgAnswer			= (CmdBase + 54);
-const unsigned	CmdMsgForward			= (CmdBase + 55);
-const unsigned	CmdCopy					= (CmdBase + 56);
-const unsigned	CmdCut					= (CmdBase + 57);
-const unsigned	CmdPaste				= (CmdBase + 58);
-const unsigned	CmdSelectAll			= (CmdBase + 59);
-const unsigned	CmdUndo					= (CmdBase + 60);
-const unsigned	CmdRedo					= (CmdBase + 61);
-const unsigned	CmdClear				= (CmdBase + 62);
-const unsigned	CmdSeparate				= (CmdBase + 63);
-const unsigned	CmdNextMessage			= (CmdBase + 65);
-const unsigned	CmdGrantAuth			= (CmdBase + 66);
-const unsigned	CmdRefuseAuth			= (CmdBase + 67);
-const unsigned	CmdPhones				= (CmdBase + 71);
-const unsigned	CmdLocation				= (CmdBase + 72);
-const unsigned	CmdPhoneState			= (CmdBase + 73);
-const unsigned	CmdPhoneNoShow			= (CmdBase + 74);
-const unsigned	CmdPhoneAvailable		= (CmdBase + 75);
-const unsigned	CmdPhoneBusy			= (CmdBase + 76);
-const unsigned  CmdPhoneBook			= (CmdBase + 77);
-const unsigned	CmdShowAlways			= (CmdBase + 78);
-const unsigned	CmdFileAccept			= (CmdBase + 79);
-const unsigned	CmdFileDecline			= (CmdBase + 80);
-const unsigned	CmdDeclineWithoutReason	= (CmdBase + 81);
-const unsigned	CmdDeclineReasonInput	= (CmdBase + 82);
-const unsigned	CmdDeclineReasonBusy	= (CmdBase + 83);
-const unsigned	CmdDeclineReasonLater	= (CmdBase + 84);
-const unsigned	CmdHistoryFind		= (CmdBase + 85);
-const unsigned	CmdFileName		= (CmdBase + 86);
-const unsigned	CmdPhoneNumber		= (CmdBase + 87);
-const unsigned	CmdTranslit		= (CmdBase + 88);
-const unsigned  CmdUrlInput		= (CmdBase + 89);
-const unsigned	CmdCutHistory		= (CmdBase + 90);
-const unsigned	CmdDeleteMessage		= (CmdBase + 91);
-const unsigned	CmdEditList				= (CmdBase + 92);
-const unsigned	CmdRemoveList			= (CmdBase + 93);
-const unsigned	CmdStatusWnd			= (CmdBase + 94);
-const unsigned	CmdEmptyGroup			= (CmdBase + 95);
-const unsigned	CmdEnableSpell			= (CmdBase + 96);
-const unsigned	CmdSpell			= (CmdBase + 97);
+const unsigned long CmdContactGroup			= (CmdBase + 0x100);
+const unsigned long CmdUnread				= (CmdBase + 0x200);
+const unsigned long CmdContactClients		= (CmdBase + 0x300);
+const unsigned long CmdMsgSpecial			= (CmdBase + 0x400);
+const unsigned long CmdClient				= (CmdBase + 0x500);
+const unsigned long CmdContactResource		= (CmdBase + 0x600);
+const unsigned long CmdReceived				= 0x600;
 
-const unsigned	CmdContactGroup			= (CmdBase + 0x100);
-const unsigned	CmdUnread				= (CmdBase + 0x200);
-const unsigned	CmdContactClients		= (CmdBase + 0x300);
-const unsigned	CmdMsgSpecial			= (CmdBase + 0x400);
-const unsigned	CmdClient				= (CmdBase + 0x500);
-const unsigned  CmdContactResource		= (CmdBase + 0x600);
-const unsigned  CmdReceived				= 0x600;
+const unsigned long MenuConnections			= (CmdBase + 1);
+const unsigned long MenuContainerContact	= (CmdBase + 2);
+const unsigned long MenuStatus				= (CmdBase + 3);
+const unsigned long MenuGroups				= (CmdBase + 4);
+const unsigned long MenuMsgView				= (CmdBase + 5);
+const unsigned long MenuTextEdit			= (CmdBase + 6);
+const unsigned long MenuMsgCommand			= (CmdBase + 7);
+const unsigned long MenuPhones				= (CmdBase + 8);
+const unsigned long MenuLocation			= (CmdBase + 9);
+const unsigned long MenuPhoneState			= (CmdBase + 10);
+const unsigned long MenuFileDecline			= (CmdBase + 11);
+const unsigned long MenuMailList			= (CmdBase + 12);
+const unsigned long MenuPhoneList			= (CmdBase + 13);
+const unsigned long MenuStatusWnd			= (CmdBase + 14);
+const unsigned long MenuEncoding			= (CmdBase + 15);
+const unsigned long MenuSearchItem			= (CmdBase + 16);
+const unsigned long MenuSearchGroups		= (CmdBase + 17);
+const unsigned long MenuSearchOptions		= (CmdBase + 18);
 
-const unsigned	MenuConnections			= (CmdBase + 1);
-const unsigned	MenuContainerContact	= (CmdBase + 2);
-const unsigned  MenuStatus				= (CmdBase + 3);
-const unsigned	MenuGroups				= (CmdBase + 4);
-const unsigned	MenuMsgView				= (CmdBase + 5);
-const unsigned	MenuTextEdit			= (CmdBase + 6);
-const unsigned	MenuMsgCommand			= (CmdBase + 7);
-const unsigned	MenuPhones				= (CmdBase + 8);
-const unsigned	MenuLocation			= (CmdBase + 9);
-const unsigned	MenuPhoneState			= (CmdBase + 10);
-const unsigned	MenuFileDecline			= (CmdBase + 11);
-const unsigned	MenuMailList			= (CmdBase + 12);
-const unsigned	MenuPhoneList			= (CmdBase + 13);
-const unsigned	MenuStatusWnd			= (CmdBase + 14);
+const unsigned long EventCreateMessageType	= (CmdBase + 1);
+const unsigned long EventRemoveMessageType	= (CmdBase + 2);
+const unsigned long EventRealSendMessage	= (CmdBase + 3);
+const unsigned long EventHistoryConfig		= (CmdBase + 4);
+const unsigned long EventTemplateExpand		= (CmdBase + 5);
+const unsigned long EventTemplateExpanded	= (CmdBase + 6);
+const unsigned long EventARRequest			= (CmdBase + 7);
+const unsigned long EventClientStatus		= (CmdBase + 8);
+const unsigned long EventLoadMessage		= (CmdBase + 9);
+const unsigned long EventDefaultAction		= (CmdBase + 10);
+const unsigned long EventContactClient      = (CmdBase + 11);
+const unsigned long EventGetIcons			= (CmdBase + 12);
+const unsigned long EventSortChanged		= (CmdBase + 13);
+const unsigned long EventActiveContact		= (CmdBase + 14);
+const unsigned long EventMessageRetry		= (CmdBase + 15);
+const unsigned long EventHistoryColors		= (CmdBase + 16);
+const unsigned long EventHistoryFont		= (CmdBase + 17);
+const unsigned long EventCheckSend			= (CmdBase + 18);
+const unsigned long EventCutHistory			= (CmdBase + 19);
+const unsigned long EventTmplHelp			= (CmdBase + 20);
+const unsigned long EventTmplHelpList		= (CmdBase + 21);
+const unsigned long EventDeleteMessage		= (CmdBase + 22);
+const unsigned long EventRewriteMessage		= (CmdBase + 23);
+const unsigned long EventJoinAlert			= (CmdBase + 24);
 
-const unsigned	EventCreateMessageType	= (CmdBase + 1);
-const unsigned	EventRemoveMessageType	= (CmdBase + 2);
-const unsigned	EventRealSendMessage	= (CmdBase + 3);
-const unsigned  EventHistoryConfig		= (CmdBase + 4);
-const unsigned	EventTemplateExpand		= (CmdBase + 5);
-const unsigned	EventTemplateExpanded	= (CmdBase + 6);
-const unsigned	EventARRequest			= (CmdBase + 7);
-const unsigned	EventClientStatus		= (CmdBase + 8);
-const unsigned	EventLoadMessage		= (CmdBase + 9);
-const unsigned	EventDefaultAction		= (CmdBase + 10);
-const unsigned	EventContactClient      = (CmdBase + 11);
-const unsigned	EventGetIcons			= (CmdBase + 12);
-const unsigned	EventSortChanged		= (CmdBase + 13);
-const unsigned	EventActiveContact		= (CmdBase + 14);
-const unsigned	EventMessageRetry		= (CmdBase + 15);
-const unsigned	EventHistoryColors		= (CmdBase + 16);
-const unsigned	EventHistoryFont		= (CmdBase + 17);
-const unsigned  EventCheckSend			= (CmdBase + 18);
-const unsigned	EventCutHistory			= (CmdBase + 19);
-const unsigned  EventTmplHelp			= (CmdBase + 20);
-const unsigned  EventTmplHelpList		= (CmdBase + 21);
-const unsigned	EventDeleteMessage		= (CmdBase + 22);
-const unsigned	EventRewriteMessage		= (CmdBase + 23);
-const unsigned	EventJoinAlert			= (CmdBase + 24);
-
-const unsigned	BarHistory				= (CmdBase + 1);
+const unsigned long BarHistory				= (CmdBase + 1);
 
 class MsgEdit;
 class Tmpl;
@@ -387,7 +389,7 @@ typedef struct MessageDef
     unsigned			flags;
     const char			*singular;
     const char			*plural;
-    Message*			(*create)(const char *cfg);
+    Message*			(*create)(Buffer *cfg);
     QObject*			(*generate)(MsgEdit *edit, Message *msg);
     Message*			(*drag)(QMimeSource*);
 } MessageDef;
@@ -406,7 +408,7 @@ class CorePlugin : public QObject, public Plugin, public EventReceiver
 {
     Q_OBJECT
 public:
-    CorePlugin(unsigned, const char*);
+    CorePlugin(unsigned, Buffer*);
     virtual ~CorePlugin();
     PROP_STR(Profile)
     PROP_BOOL(SavePasswd)
@@ -459,10 +461,12 @@ public:
     PROP_ULONG(InvisibleStyle);
     PROP_BOOL(SmallGroupFont);
     PROP_BOOL(ShowAllEncodings);
-    PROP_STR(DefaultEncoding);
     PROP_BOOL(ShowEmptyGroup);
     PROP_BOOL(NoJoinAlert);
     PROP_BOOL(EnableSpell);
+    PROP_BOOL(RemoveHistory);
+    PROP_STR(SearchClient);
+    PROP_BOOL(NoScroller);
 
     unsigned user_data_id;
     unsigned sms_data_id;
@@ -479,15 +483,12 @@ public:
 
     QFont editFont;
     static CorePlugin	*m_plugin;
-    Message *createMessage(const char *type, const char *cfg);
+    Message *createMessage(const char *type, Buffer *cfg);
     QString clientName(Client *client);
 
     XSL	*historyXSL;
     CoreData	data;
-
     bool m_bIgnoreEvents;
-    const ENCODING *encodings;
-
 signals:
     void modeChanged();
 protected slots:
@@ -511,7 +512,7 @@ protected:
     void loadClients(ClientList&);
     void loadMenu();
     QString poFile(const char *lang);
-    Client *loadClient(const char *name, const char *cfg);
+    Client *loadClient(const char *name, Buffer *cfg);
     void setCurrentProfile(const char *profile);
     bool adjustClientItem(unsigned id, CommandDef *cmd);
     void showPanel();
@@ -542,7 +543,6 @@ protected:
     unsigned			m_nResourceMenu;
     Commands			*m_cmds;
     MainWindow			*m_main;
-    Icons				*m_icons;
     Tmpl				*m_tmpl;
     BalloonMsg			*m_alert;
     FileLock			*m_lock;
