@@ -29,6 +29,8 @@
 #include <qtimer.h>
 #include <qframe.h>
 #include <qtoolbutton.h>
+#include <qpainter.h>
+#include <qimage.h>
 
 StatusLabel::StatusLabel(QWidget *parent, Client *client, unsigned id)
         : QLabel(parent)
@@ -107,15 +109,15 @@ void StatusLabel::setPict()
             }
         }
     }
-    QPixmap pict = Pict(icon.c_str());
+    QPixmap p = Pict(icon.c_str());
+    setPixmap(p);
     QString tip = CorePlugin::m_plugin->clientName(m_client);
     tip += "\n";
     tip += i18n(text);
-    setPixmap(pict);
     QToolTip::add(this, tip);
-    resize(pict.width(), pict.height());
-    setFixedSize(pict.width(), pict.height());
-};
+    resize(p.width(), p.height());
+    setFixedSize(p.width(), p.height());
+}
 
 void StatusLabel::timeout()
 {
@@ -244,24 +246,6 @@ void *StatusFrame::processEvent(Event *e)
                 lbl->setPict();
             break;
         }
-    case EventClientError:
-        if (isVisible()){
-            clientErrorData *data = (clientErrorData*)(e->param());
-            if (data->code == AuthError)
-                break;
-            StatusLabel *lbl = findLabel(data->client);
-            if (lbl == NULL)
-                break;
-            if (data->err_str && *data->err_str){
-                QString msg = i18n(data->err_str);
-                if (data->args)
-                    msg = msg.arg(QString::fromUtf8(data->args));
-                raiseWindow(topLevelWidget());
-                BalloonMsg::message(msg, lbl);
-                return e->param();
-            }
-        }
-        break;
     case EventIconChanged:{
             QObjectList *l = queryList("StatusLabel");
             QObjectListIt itObject(*l);
@@ -409,7 +393,19 @@ void StatusWnd::clicked()
     }
 }
 
-#ifndef WIN32
+BalloonMsg *StatusWnd::showError(const QString &text, QStringList &buttons, Client *client)
+{
+    if (!isVisible())
+        return NULL;
+    StatusLabel *lbl = m_frame->findLabel(client);
+    if (lbl == NULL)
+        return NULL;
+    if (lbl->x() + lbl->width() > width())
+        return NULL;
+    return new BalloonMsg(NULL, text, buttons, lbl);
+}
+
+#ifndef _MSC_VER
 #include "statuswnd.moc"
 #endif
 
