@@ -830,7 +830,7 @@ static void resort(QListViewItem *item)
     if (!item->isExpandable())
         return;
     item->sort();
-    for (item = item->firstChild(); item; item = item = item->nextSibling())
+    for (item = item->firstChild(); item; item = item->nextSibling())
         resort(item);
 }
 
