@@ -43,6 +43,7 @@ public:
     UserViewItemBase(UserListBase *view);
     UserViewItemBase(UserViewItemBase *parent);
     virtual unsigned type() = 0;
+    virtual void setup();
     virtual void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int align);
     virtual void paintFocus(QPainter*, const QColorGroup&, const QRect & );
     int drawText(QPainter *p, int x, int width, const QString &text);
@@ -66,7 +67,7 @@ public:
     GroupItem(UserListBase *view, Group *grp, bool bOffline);
     GroupItem(UserViewItemBase *view, Group *grp, bool bOffline);
     unsigned type() { return GRP_ITEM; }
-    unsigned id() { return m_id; }
+    unsigned long id() { return m_id; }
     void update(Group *grp, bool bInit=false);
     unsigned m_nContacts;
     unsigned m_nContactsOnline;
@@ -74,7 +75,7 @@ public:
 protected:
     virtual void setOpen(bool bOpen);
     void init(Group *grp);
-    unsigned m_id;
+    unsigned long m_id;
     bool m_bOffline;
 };
 
@@ -83,7 +84,7 @@ class ContactItem : public UserViewItemBase
 public:
     ContactItem(UserViewItemBase *view, Contact *contact, unsigned status, unsigned style, const char *icons, unsigned unread);
     unsigned type() { return USR_ITEM; }
-    unsigned id() { return m_id; }
+    unsigned long id() { return m_id; }
     unsigned style() { return m_style; }
     unsigned status() { return m_status; }
     bool update(Contact *grp, unsigned status, unsigned style, const char *icons, unsigned unread);
@@ -93,7 +94,7 @@ public:
 protected:
     virtual QString key(int column, bool ascending) const;
     void init(Contact *contact, unsigned status, unsigned style, const char *icons, unsigned unread);
-    unsigned m_id;
+    unsigned long m_id;
     unsigned m_style;
     unsigned m_status;
 };
@@ -113,15 +114,18 @@ protected:
     unsigned m_bShowEmpty;
     void *processEvent(Event*);
     virtual void drawItem(UserViewItemBase *base, QPainter *p, const QColorGroup &cg, int width, int margin);
+    virtual int heightItem(UserViewItemBase *base);
     unsigned getUserStatus(Contact *contact, unsigned &style, string &icons);
     virtual unsigned getUnread(unsigned contact_id);
     GroupItem *findGroupItem(unsigned id, QListViewItem *p = NULL);
     ContactItem *findContactItem(unsigned id, QListViewItem *p = NULL);
     void addSortItem(QListViewItem *item);
+    void addUpdatedItem(QListViewItem *item);
     void addGroupForUpdate(unsigned long id);
     void addContactForUpdate(unsigned long id);
     virtual void deleteItem(QListViewItem *item);
     list<QListViewItem*> sortItems;
+    list<QListViewItem*> updatedItems;
     list<unsigned long>	updGroups;
     list<unsigned long>	updContacts;
     bool m_bDirty;
