@@ -32,7 +32,7 @@
 #include <kwin.h>
 #endif
 
-FloatyWnd::FloatyWnd(FloatyPlugin *plugin, unsigned id)
+FloatyWnd::FloatyWnd(FloatyPlugin *plugin, unsigned long id)
         : QWidget(NULL, "floaty",
                   WType_TopLevel | WStyle_Customize | WStyle_NoBorder | WStyle_Tool |
                   WStyle_StaysOnTop | WRepaintNoErase)
@@ -134,6 +134,7 @@ void FloatyWnd::paintEvent(QPaintEvent*)
     }else{
         switch (m_status){
         case STATUS_ONLINE:
+            p.setPen(m_plugin->core->getColorOnline());
             break;
         case STATUS_AWAY:
             p.setPen(m_plugin->core->getColorAway());
@@ -405,7 +406,7 @@ void FloatyWnd::dragEvent(QDropEvent *e, bool isDrop)
     }
 }
 
-#ifndef WIN32
+#ifndef _MSC_VER
 #include "floatywnd.moc"
 #endif
 
