@@ -27,6 +27,8 @@
 
 #include <windows.h>
 
+using namespace SIM;
+
 GpgFind::GpgFind(EditFile *edt)
         : GpgFindBase(NULL, NULL, false, WDestructiveClose)
 {
@@ -110,6 +112,6 @@ bool GpgFind::checkPath()
     return false;
 }
 
-#ifndef WIN32
+#ifndef _MSC_VER
 #include "gpgfind.moc"
 #endif
