@@ -27,7 +27,7 @@ class AboutInfo : public AboutInfoBase, public EventReceiver
 {
     Q_OBJECT
 public:
-    AboutInfo(QWidget *parent, struct ICQUserData *data, ICQClient *client);
+    AboutInfo(QWidget *parent, struct ICQUserData *data, unsigned contact, ICQClient *client);
 public slots:
     void apply();
     void apply(Client*, void*);
@@ -35,6 +35,7 @@ protected:
     void *processEvent(Event*);
     void fill();
     struct ICQUserData	*m_data;
+    unsigned	m_contact;
     ICQClient	*m_client;
 };
 
