@@ -166,6 +166,7 @@ typedef struct ICQUserData
     Data		Port;
     Data		DCcookie;
     Data		Caps;
+    Data		Caps2;
     Data        AutoReply;
     Data		Uin;
     Data        Screen;
@@ -255,6 +256,7 @@ typedef struct ICQClientData
     Data		ContactsInvisible;
     Data		HideIP;
     Data		IgnoreAuth;
+    Data		UseMD5;
     Data		DirectMode;
     Data		IdleTime;
     Data        ListRequests;
@@ -294,30 +296,50 @@ class QTimer;
 typedef unsigned char capability[0x10];
 typedef unsigned char plugin[0x12];
 
-const unsigned CAP_DIRECT			= 0;
-const unsigned CAP_RTF				= 1;
-const unsigned CAP_SRV_RELAY		= 2;
-const unsigned CAP_UTF				= 3;
-const unsigned CAP_TYPING			= 4;
-const unsigned CAP_AIM_SUPPORT		= 5;
-const unsigned CAP_SIM				= 6;
-const unsigned CAP_STR_2001			= 7;
-const unsigned CAP_IS_2001			= 8;
-const unsigned CAP_TRILLIAN			= 9;
-const unsigned CAP_TRIL_CRYPT		= 10;
-const unsigned CAP_MACICQ			= 11;
-const unsigned CAP_AIM_CHAT			= 12;
-const unsigned CAP_AIM_BUDDYCON		= 13;
-const unsigned CAP_AIM_IMIMAGE		= 14;
-const unsigned CAP_AIM_SENDFILE		= 15;
-const unsigned CAP_AIM_BUDDYLIST	= 16;
-const unsigned CAP_MICQ				= 17;
-const unsigned CAP_LICQ				= 18;
-const unsigned CAP_SIMOLD			= 19;
-const unsigned CAP_KOPETE			= 20;
-const unsigned CAP_XTRAZ			= 21;
-const unsigned CAP_IS_2002			= 21;
-const unsigned CAP_NULL				= 22;
+typedef enum {
+    CAP_AIM_SHORTCAPS = 0,      // 0x00000001
+    CAP_AIM_VOICE,              // 0x00000002
+    CAP_AIM_SENDFILE,           // 0x00000004
+    CAP_DIRECT,                 // 0x00000008
+    CAP_AIM_IMIMAGE,            // 0x00000010
+    CAP_AIM_BUDDYCON,           // 0x00000020
+    CAP_AIM_STOCKS,             // 0x00000040
+    CAP_AIM_GETFILE,            // 0x00000080
+    CAP_SRV_RELAY,              // 0x00000100
+    CAP_AIM_GAMES,              // 0x00000200
+    CAP_AIM_BUDDYLIST,          // 0x00000400
+    CAP_AVATAR,                 // 0x00000800
+    CAP_AIM_SUPPORT,            // 0x00001000
+    CAP_UTF,                    // 0x00002000
+    CAP_RTF,                    // 0x00004000
+    CAP_TYPING,                 // 0x00008000
+    CAP_SIM,                    // 0x00010000
+    CAP_STR_2001,               // 0x00020000
+    CAP_STR_2002,               // 0x00040000
+    CAP_IS_2001,                // 0x00080000
+    CAP_TRILLIAN,               // 0x00100000
+    CAP_TRIL_CRYPT,             // 0x00200000
+    CAP_MACICQ,                 // 0x00400000
+    CAP_AIM_CHAT,               // 0x00800000
+    CAP_MICQ,                   // 0x01000000
+    CAP_LICQ,                   // 0x02000000
+    CAP_SIMOLD,                 // 0x04000000
+    CAP_KOPETE,                 // 0x08000000
+    CAP_XTRAZ,                  // 0x10000000
+    CAP_IS_2002,                // 0x20000000
+    CAP_MIRANDA,                // 0x40000000
+    CAP_ANDRQ,                  // 0x80000000
+    CAP_QIP,                    // 0x00000001 - Caps2
+    CAP_IMSECURE,               // 0x00000002
+    CAP_KXICQ,                  // 0x00000004
+    CAP_ICQ5_1,                 // 0x00000008
+    CAP_UNKNOWN,                // 0x00000010
+    CAP_ICQ5_3,                 // 0x00000020
+    CAP_ICQ5_4,                 // 0x00000040
+    CAP_ICQ51,                  // 0x00000080
+    CAP_JIMM,                   // 0x00000100
+    CAP_NULL,                   // 0x00000200
+} cap_id_t;
 
 const unsigned PLUGIN_PHONEBOOK          = 0;
 const unsigned PLUGIN_PICTURE            = 1;
@@ -493,6 +515,7 @@ public:
     PROP_USHORT(ContactsInvisible);
     PROP_BOOL(HideIP);
     PROP_BOOL(IgnoreAuth);
+    PROP_BOOL(UseMD5);
     PROP_ULONG(DirectMode);
     PROP_ULONG(IdleTime);
     PROP_STR(ListRequests);
@@ -537,7 +560,7 @@ public:
     ListRequest *findGroupListRequest(unsigned short id);
     void removeListRequest(ListRequest *lr);
     virtual void setupContact(Contact*, void *data);
-    string clientName(ICQUserData*);
+    QString clientName(ICQUserData*);
     void sendStatus();
     void sendUpdate();
     void changePassword(const char *new_pswd);
@@ -554,7 +577,7 @@ public:
     Message *parseMessage(unsigned short type, const char *screen,
                           string &p, Buffer &packet, MessageId &id, unsigned cookie);
     bool messageReceived(Message*, const char *screen);
-    static bool parseRTF(const char *str, Contact *contact, QString &result);
+    static bool parseRTF(const QCString &str, Contact *contact, QString &result);
     static QString pictureFile(ICQUserData *data);
     static const capability *capabilities;
     static const plugin *plugins;
@@ -616,7 +639,8 @@ protected:
     void buddyRequest();
     void icmbRequest();
     void bosRequest();
-    void sendCapability(const char *msg=NULL);
+    void addCapability(Buffer &cap, cap_id_t id);   // helper for sendCapability()
+    void sendCapability(const QString &msg = QString::null);
     void sendICMB(unsigned short channel, unsigned long flags);
     void sendLogonStatus();
     void sendClientReady();
@@ -675,7 +699,8 @@ protected:
     void sendPluginInfoUpdate(unsigned plugin_id);
     void sendPluginStatusUpdate(unsigned plugin_id, unsigned long status);
     bool m_bIdleTime;
-    bool hasCap(ICQUserData *data, int fcap);
+    static bool hasCap(const ICQUserData *data, cap_id_t fcap);
+    static void setCap(ICQUserData *data, cap_id_t fcap);
     bool isSupportPlugins(ICQUserData *data);
     string trimPhone(const char *phone);
     unsigned short getListId();
