@@ -1267,6 +1267,7 @@ bool DirectClient::sendMessage(Message *msg)
     sm.msg	= msg;
     sm.seq	= 0;
     sm.type	= 0;
+    sm.icq_type = 0;
     m_queue.push_back(sm);
     processMsgQueue();
     return true;
@@ -1880,8 +1881,7 @@ void ICQFileTransfer::write_ready()
             m_notify->process();
         return;
     }
-    time_t now;
-    time(&now);
+    time_t now = time(NULL);
     if ((unsigned)now != m_sendTime){
         m_sendTime = now;
         m_sendSize = 0;
