@@ -366,14 +366,15 @@ void ICQClient::snac_icmb(unsigned short type, unsigned short seq)
             log(L_DEBUG, "Message from %s [%04X]", screen.c_str(), mFormat);
             unsigned short level, nTLV;
             m_socket->readBuffer >> level >> nTLV;
-            TlvList tlv(m_socket->readBuffer);
+            TlvList tlvFixed(socket()->readBuffer, nTLV);
+            TlvList tlvChannel(socket()->readBuffer);
             switch (mFormat){
             case 0x0001:{
-                    if (!tlv(2)){
+                    if (!tlvChannel(2)){
                         log(L_WARN, "TLV 0x0005 not found");
                         break;
                     }
-                    Buffer m(*tlv(2));
+                    Buffer m(*tlvChannel(2));
                     TlvList tlv_msg(m);
                     Tlv *m_tlv = tlv_msg(0x101);
                     if (m_tlv == NULL){
@@ -426,14 +427,7 @@ void ICQClient::snac_icmb(unsigned short type, unsigned short seq)
                     break;
                 }
             case 0x0002:{
-                    int iSkip = 0;
-                    Tlv *tlv5 = tlv(5, iSkip);
-                    // sometimes a message contains two Tlv(5) - messages
-                    // skip the one with size == 4 -> account creation time
-                    for( ; tlv5 && tlv5->Size() < 10; ) {
-                        iSkip++;
-                        tlv5 = tlv(5, iSkip);
-                    }
+                    Tlv *tlv5 = tlvChannel(5);
                     if (!tlv5){
                         log(L_WARN, "TLV 0x0005 not found");
                         break;
@@ -443,7 +437,7 @@ void ICQClient::snac_icmb(unsigned short type, unsigned short seq)
                     msg >> type;
                     switch (type){
                     case 0:
-                        parseAdvancedMessage(screen.c_str(), msg, tlv(3) != NULL, id);
+                        parseAdvancedMessage(screen.c_str(), msg, tlvChannel(3) != NULL, id);
                         break;
                     case 1:{
                             Contact *contact;
@@ -485,14 +479,7 @@ void ICQClient::snac_icmb(unsigned short type, unsigned short seq)
                     break;
                 }
             case 0x0004:{
-                    int iSkip = 0;
-                    Tlv *tlv5 = tlv(5, iSkip);
-                    // sometimes a message contains two Tlv(5) - messages
-                    // skip the one with size == 4 -> account creation time
-                    for( ; tlv5 && tlv5->Size() < 10; ) {
-                        iSkip++;
-                        tlv5 = tlv(5, iSkip);
-                    }
+                    Tlv *tlv5 = tlvChannel(5);
                     if (!tlv5){
                         log(L_WARN, "TLV 0x0005 not found");
                         break;
@@ -501,7 +488,7 @@ void ICQClient::snac_icmb(unsigned short type, unsigned short seq)
                     unsigned long msg_uin;
                     msg >> msg_uin;
                     if (msg_uin == 0){
-                        parseAdvancedMessage(screen.c_str(), msg, tlv(6) != NULL, id);
+                        parseAdvancedMessage(screen.c_str(), msg, tlvChannel(6) != NULL, id);
                         return;
                     }
                     unsigned char type, flags;
