@@ -22,11 +22,12 @@
 #include <qlineedit.h>
 #include <qcombobox.h>
 
-InterestsInfo::InterestsInfo(QWidget *parent, struct ICQUserData *data, ICQClient *client)
+InterestsInfo::InterestsInfo(QWidget *parent, struct ICQUserData *data, unsigned contact, ICQClient *client)
         : InterestsInfoBase(parent)
 {
-    m_data   = data;
-    m_client = client;
+    m_data    = data;
+    m_client  = client;
+    m_contact = contact;
     if (m_data){
         edtBg1->setReadOnly(true);
         edtBg2->setReadOnly(true);
@@ -67,7 +68,7 @@ void InterestsInfo::apply(Client *client, void *_data)
             res += ";";
         res += info[i];
     }
-    set_str(&data->Interests.ptr, m_client->fromUnicode(res, NULL).c_str());
+    set_str(&data->Interests.ptr, getContacts()->fromUnicode(NULL, res).c_str());
 }
 
 void *InterestsInfo::processEvent(Event *e)
@@ -141,12 +142,14 @@ static const ext_info interests[] =
         { "", 0  }
     };
 
+const ext_info *p_interests = interests;
+
 void InterestsInfo::fill()
 {
     ICQUserData *data = m_data;
     if (data == NULL) data = &m_client->data.owner;
     unsigned i = 0;
-    QString str = m_client->toUnicode(data->Interests.ptr, data);
+    QString str = getContacts()->toUnicode(getContacts()->contact(m_contact), data->Interests.ptr);
     while (str.length()){
         QString info = getToken(str, ';', false);
         QString n = getToken(info, ',');
@@ -217,6 +220,7 @@ void InterestsInfo::cmbChanged(int)
                 edts[n]->setText(edts[i]->text());
             }
             edts[n]->setEnabled(true);
+            edts[n]->setReadOnly(false);
             n++;
         }
     }
@@ -234,7 +238,7 @@ void InterestsInfo::cmbChanged(int)
     }
 }
 
-#ifndef WIN32
+#ifndef _MSC_VER
 #include "interestsinfo.moc"
 #endif
 
