@@ -111,6 +111,8 @@ DataDef jabberUserData[] =
         { "Group", DATA_UTF, 1, 0 },
         { "", DATA_BOOL, 1, 0 },			// bChecked
         { "", DATA_STRING, 1, 0 },			// TypingId
+        { "", DATA_BOOL, 1, 0 },			// SendTypingEvents
+        { "", DATA_BOOL, 1, 0 },			// IsTyping
         { "", DATA_ULONG, 1, 0 },			// ComposeId
         { "", DATA_ULONG, 1, DATA(1) },			// richText
         { "", DATA_BOOL, 1, 0 },
@@ -125,6 +127,9 @@ DataDef jabberUserData[] =
         { "", DATA_STRLIST, 1, 0 },			// ResourceStatusTime
         { "", DATA_STRLIST, 1, 0 },			// ResourceOnlineTime
         { "AutoReply", DATA_UTF, 1, 0 },
+        { "", DATA_STRLIST, 1, 0 },			// ResourceClientName
+        { "", DATA_STRLIST, 1, 0 },			// ResourceClientVersion
+        { "", DATA_STRLIST, 1, 0 },			// ResourceClientOS
         { NULL, 0, 0, 0 }
     };
 
@@ -154,6 +159,7 @@ static DataDef jabberClientData[] =
         { "VHost", DATA_UTF, 1, 0 },
         { "Typing", DATA_BOOL, 1, DATA(1) },
         { "RichText", DATA_BOOL, 1, DATA(1) },
+        { "UseVersion", DATA_BOOL, 1, DATA(1) },
         { "ProtocolIcons", DATA_BOOL, 1, DATA(1) },
         { "MinPort", DATA_ULONG, 1, DATA(1024) },
         { "MaxPort", DATA_ULONG, 1, DATA(0xFFFF) },
@@ -180,11 +186,6 @@ JabberClient::JabberClient(JabberProtocol *protocol, Buffer *cfg)
     }
     if (data.owner.Resource.ptr == NULL){
         string resource = PACKAGE;
-        resource += "_";
-        resource += VERSION;
-#ifdef WIN32
-        resource += "/win32";
-#endif
         set_str(&data.owner.Resource.ptr, resource.c_str());
     }
 
@@ -224,7 +225,7 @@ bool JabberClient::compareData(void *d1, void *d2)
 {
     JabberUserData *data1 = (JabberUserData*)d1;
     JabberUserData *data2 = (JabberUserData*)d2;
-    return strcmp(data1->ID.ptr, data2->ID.ptr) == 0;
+    return strcasecmp(data1->ID.ptr, data2->ID.ptr) == 0;
 }
 
 void JabberClient::setID(const QString &id)
@@ -525,6 +526,27 @@ void *JabberClient::processEvent(Event *e)
         }
         return NULL;
     }
+    if (e->type() == EventClientVersion){
+        ClientVersionInfo* info = static_cast<ClientVersionInfo*>(e->param());
+        if (!info->jid.isEmpty()){
+            Contact *contact;
+            string resource;
+            JabberUserData* data = findContact(info->jid.utf8(), NULL, false, contact, resource);
+            if (!data)
+                return NULL;
+            unsigned i;
+            for (i = 1; i <= data->nResources.value; i++){
+                if (resource == get_str(data->Resources, i))
+                    break;
+            }
+            if (i <= data->nResources.value){
+                set_str(&data->ResourceClientName, i, info->name);
+                set_str(&data->ResourceClientVersion, i, info->version);
+                set_str(&data->ResourceClientOS, i, info->os);
+            }
+        }
+        return NULL;
+    }
     return NULL;
 }
 
@@ -829,7 +851,7 @@ void JabberClient::ServerRequest::start_element(const char *name)
 void JabberClient::ServerRequest::add_attribute(const char *name, const char *value)
 {
     m_client->m_socket->writeBuffer
-    << " " << name << "=\'" 
+    << " " << name << "=\'"
     << JabberClient::encodeXML(QString::fromUtf8(value)).replace('\'', "&apos;")
     << "\'";
 }
@@ -990,7 +1012,7 @@ JabberUserData *JabberClient::findContact(const char *_jid, const char *name, bo
         JabberUserData *data;
         ClientDataIterator it(contact->clientData, this);
         while ((data = (JabberUserData*)(++it)) != NULL){
-            if (jid != data->ID.ptr)
+            if (QString::fromUtf8(jid.c_str()).upper() != QString::fromUtf8(data->ID.ptr).upper())
                 continue;
             if (!resource.empty())
                 set_str(&data->Resource.ptr, resource.c_str());
@@ -1073,16 +1095,19 @@ const char *JabberClient::get_icon(JabberUserData *data, unsigned status, bool i
         dicon = "Jabber_invisible";
     if (getProtocolIcons()){
         char *host = strchr(data->ID.ptr, '@');
-        if (host){
-            string h = host + 1;
-            char *p = strchr((char*)(h.c_str()), '.');
-            if (p)
-                *p = 0;
-            if (strcmp(h.c_str(), "icq") == 0){
-                if (invisible){
-                    dicon = "ICQ_invisible";
-                }else{
-                    switch (status){
+        string h;
+        if (host)
+            h = host + 1;
+        else
+            h = data->ID.ptr;
+        char *p = strchr((char*)(h.c_str()), '.');
+        if (p)
+            *p = 0;
+        if (strcmp(h.c_str(), "icq") == 0){
+            if (invisible){
+                dicon = "ICQ_invisible";
+            }else{
+                switch (status){
                     case STATUS_ONLINE:
                         dicon = "ICQ_online";
                         break;
@@ -1101,10 +1126,10 @@ const char *JabberClient::get_icon(JabberUserData *data, unsigned status, bool i
                     case STATUS_FFC:
                         dicon = "ICQ_ffc";
                         break;
-                    }
                 }
-            }else if (strcmp(h.c_str(), "aim") == 0){
-                switch (status){
+            }
+        }else if (strcmp(h.c_str(), "aim") == 0){
+            switch (status){
                 case STATUS_ONLINE:
                     dicon = "AIM_online";
                     break;
@@ -1114,12 +1139,12 @@ const char *JabberClient::get_icon(JabberUserData *data, unsigned status, bool i
                 case STATUS_AWAY:
                     dicon = "AIM_away";
                     break;
-                }
-            }else if (strcmp(h.c_str(), "msn") == 0){
-                if (invisible){
-                    dicon = "MSN_invisible";
-                }else{
-                    switch (status){
+            }
+        }else if (strcmp(h.c_str(), "msn") == 0){
+            if (invisible){
+                dicon = "MSN_invisible";
+            }else{
+                switch (status){
                     case STATUS_ONLINE:
                         dicon = "MSN_online";
                         break;
@@ -1135,10 +1160,10 @@ const char *JabberClient::get_icon(JabberUserData *data, unsigned status, bool i
                     case STATUS_DND:
                         dicon = "MSN_dnd";
                         break;
-                    }
                 }
-            }else if (strcmp(h.c_str(), "yahoo") == 0){
-                switch (status){
+            }
+        }else if (strcmp(h.c_str(), "yahoo") == 0){
+            switch (status){
                 case STATUS_ONLINE:
                     dicon = "Yahoo!_online";
                     break;
@@ -1157,7 +1182,48 @@ const char *JabberClient::get_icon(JabberUserData *data, unsigned status, bool i
                 case STATUS_FFC:
                     dicon = "Yahoo!_ffc";
                     break;
-                }
+            }
+        }else if (strcmp(h.c_str(), "sms") == 0){
+            switch (status){
+                case STATUS_ONLINE:
+                dicon = "sms_online";
+                break;
+                case STATUS_OFFLINE:
+                dicon = "sms_offline";
+                break;
+                case STATUS_AWAY:
+                dicon = "sms_away";
+                break;
+                case STATUS_NA:
+                dicon = "sms_na";
+                break;
+                case STATUS_DND:
+                dicon = "sms_dnd";
+                break;
+                case STATUS_FFC:
+                dicon = "sms_ffc";
+                break;
+            }
+        }else if ((strcmp(h.c_str(), "x-gadugadu") == 0) || (strcmp(h.c_str(), "gg") == 0)){
+            switch (status){
+                case STATUS_ONLINE:
+                dicon = "GG_online";
+                break;
+                case STATUS_OFFLINE:
+                dicon = "GG_offline";
+                break;
+                case STATUS_AWAY:
+                dicon = "GG_away";
+                break;
+                case STATUS_NA:
+                dicon = "GG_na";
+                break;
+                case STATUS_DND:
+                dicon = "GG_dnd";
+                break;
+                case STATUS_FFC:
+                dicon = "GG_ffc";
+                break;
             }
         }
     }
@@ -1190,7 +1256,7 @@ void JabberClient::contactInfo(void *_data, unsigned long &curStatus, unsigned &
     }
     if (((data->Subscribe.value & SUBSCRIBE_TO) == 0) && !isAgent(data->ID.ptr))
         style |= CONTACT_UNDERLINE;
-    if (icons && data->TypingId.ptr && *data->TypingId.ptr)
+    if (icons && data->IsTyping.bValue)
         addIcon(icons, "typing", statusIcon);
 }
 
@@ -1259,11 +1325,12 @@ QString JabberClient::contactTip(void *_data)
         res += "<br/>";
         res += "ID: <b>";
         res += QString::fromUtf8(data->ID.ptr);
-        res += "</b>";
         if (data->Resource.ptr && *data->Resource.ptr){
-            res += "<br/>";
+            res += "/";
             res += QString::fromUtf8(data->Resource.ptr);
         }
+        res += "</b>";
+
         if (data->StatusTime.value){
             res += "<br/><font size=-1>";
             res += i18n("Last online");
@@ -1293,9 +1360,13 @@ QString JabberClient::contactTip(void *_data)
             }
             res += "<br/>ID: <b>";
             res += QString::fromUtf8(data->ID.ptr);
-            res += "</b><br/>";
-            res += QString::fromUtf8(get_str(data->Resources, i));
-            res += "<br/>";
+            QString resource = get_str(data->Resources, i);
+            if (!resource.isEmpty()){
+                res += "/";
+                res += resource;
+            }
+            res += "</b>";
+
             unsigned onlineTime = atol(get_str(data->ResourceOnlineTime, i));
             unsigned statusTime = atol(get_str(data->ResourceStatusTime, i));
             if (onlineTime){
@@ -1310,9 +1381,19 @@ QString JabberClient::contactTip(void *_data)
                 res += ": </font>";
                 res += formatDateTime(statusTime);
             }
+
+            QString clientName = get_str(data->ResourceClientName, i);
+            QString clientVersion = get_str(data->ResourceClientVersion, i);
+            QString clientOS = get_str(data->ResourceClientOS, i);
+            if (!clientName.isEmpty()) {
+                res += "<br/>" + clientName + " " + clientVersion;
+                if (!clientOS.isEmpty())
+                    res += " / " + clientOS;
+            }
+
             const char *reply = get_str(data->ResourceReply, i);
             if (reply && *reply){
-                res += "<br/>";
+                res += "<br/><br/>";
                 QString r = QString::fromUtf8(reply);
                 r = r.replace(QRegExp("\n"), "<br/>");
                 res += r;
@@ -1340,8 +1421,12 @@ QString JabberClient::contactTip(void *_data)
                     w = 60;
                 }
             }
-            QMimeSourceFactory::defaultFactory()->setPixmap("pict://jabber.logo", pict);
-            res += "<br/><img src=\"pict://jabber.logo\" width=\"";
+            QString url="pict://jabber.logo.";
+            url += data->ID.ptr;
+            QMimeSourceFactory::defaultFactory()->setPixmap(static_cast<const char *>(url.utf8()), pict);
+            res += "<br/><img src=\"";
+            res += static_cast<const char *>(url.utf8());
+            res += "\" width=\"";
             res += number(w).c_str();
             res += "\" height=\"";
             res += number(h).c_str();
@@ -1366,8 +1451,12 @@ QString JabberClient::contactTip(void *_data)
                     w = 60;
                 }
             }
-            QMimeSourceFactory::defaultFactory()->setPixmap("pict://jabber.photo", pict);
-            res += "<br/><img src=\"pict://jabber.photo\" width=\"";
+            QString url="pict://jabber.photo.";
+            url += data->ID.ptr;
+            QMimeSourceFactory::defaultFactory()->setPixmap(static_cast<const char *>(url.utf8()), pict);
+            res += "<br/><img src=\"";
+            res += static_cast<const char *>(url.utf8());
+            res += "\" width=\"";
             res += number(w).c_str();
             res += "\" height=\"";
             res += number(h).c_str();
@@ -1387,8 +1476,9 @@ void JabberClient::setOffline(JabberUserData *data)
     clear_list(&data->ResourceStatusTime);
     clear_list(&data->ResourceOnlineTime);
     data->nResources.value = 0;
-    if (data->TypingId.ptr && *data->TypingId.ptr){
-        set_str(&data->TypingId.ptr, NULL);
+    set_str(&data->TypingId.ptr, NULL);
+    if (data->IsTyping.bValue){
+        data->IsTyping.bValue = false;      
         Contact *contact;
         string resource;
         if (findContact(data->ID.ptr, NULL, false, contact, resource)){
@@ -1742,11 +1832,11 @@ bool JabberClient::canSend(unsigned type, void *_data)
     case MessageUrl:
         return true;
     case MessageAuthRequest:
-        return ((data->Subscribe.value & SUBSCRIBE_TO) == 0) && !isAgent(data->ID.ptr);
+        return ((data->Subscribe.value & SUBSCRIBE_TO) == 0);
     case MessageAuthGranted:
-        return ((data->Subscribe.value & SUBSCRIBE_FROM) == 0) && !isAgent(data->ID.ptr);
+        return ((data->Subscribe.value & SUBSCRIBE_FROM) == 0);
     case MessageAuthRefused:
-        return (data->Subscribe.value & SUBSCRIBE_FROM) && !isAgent(data->ID.ptr);
+        return (data->Subscribe.value & SUBSCRIBE_FROM);
     case MessageJabberOnline:
         return isAgent(data->ID.ptr) && (data->Status.value == STATUS_OFFLINE);
     case MessageJabberOffline:
@@ -2108,6 +2198,13 @@ bool JabberClient::send(Message *msg, void *_data)
                 << "/"
                 << msg->getResource().utf8();
             }
+            if (getTyping()){
+                data->composeId.value = ++m_msg_id;
+                string msg_id = "msg";
+                msg_id += number(data->composeId.value);
+                m_socket->writeBuffer
+                <<"\' id=\'"<<msg_id.c_str();
+            }
             m_socket->writeBuffer
             << "\'><body>"
             << (const char*)(quote_nbsp(quoteString(QString::fromUtf8(text.c_str()), quoteNOBR)).utf8())
@@ -2118,6 +2215,12 @@ bool JabberClient::send(Message *msg, void *_data)
                 << quote_nbsp(removeImages(msg->getRichText(), msg->getBackground())).utf8()
                 << "</body></html>";
             }
+            if (getTyping()){
+                m_socket->writeBuffer
+                <<"<x xmlns='jabber:x:event'>"
+                <<"<composing/>"
+                <<"</x>";
+            }
             m_socket->writeBuffer
             << "</message>";
             sendPacket();
@@ -2392,15 +2495,13 @@ bool JabberClient::send(Message *msg, void *_data)
         break;
     case MessageTypingStart:
         if (getTyping()){
-            data->composeId.value = ++m_msg_id;
-            string msg_id = "msg";
-            msg_id += number(data->composeId.value);
             m_socket->writeBuffer.packetStart();
             m_socket->writeBuffer
             << "<message to=\'"
             << data->ID.ptr
             << "\'><x xmlns='jabber:x:event'><composing/><id>"
-            << msg_id.c_str()
+            //<< msg_id.c_str()
+            << (data->TypingId.ptr ? data->TypingId.ptr : "")
             << "</id></x></message>";
             sendPacket();
             delete msg;
@@ -2409,16 +2510,12 @@ bool JabberClient::send(Message *msg, void *_data)
         break;
     case MessageTypingStop:
         if (getTyping()){
-            if (data->composeId.value == 0)
-                return false;
-            string msg_id = "msg";
-            msg_id += number(data->composeId.value);
             m_socket->writeBuffer.packetStart();
             m_socket->writeBuffer
             << "<message to=\'"
             << data->ID.ptr
             << "\'><x xmlns='jabber:x:event'><id>"
-            << msg_id.c_str()
+            << (data->TypingId.ptr ? data->TypingId.ptr : "")//msg_id.c_str()
             << "</id></x></message>";
             sendPacket();
             delete msg;
@@ -2478,8 +2575,7 @@ JabberListRequest *JabberClient::findRequest(const char *jid, bool bRemove)
 
 bool JabberClient::isAgent(const char *jid)
 {
-    const char *p = strrchr(jid, '/');
-    if (p && !strcmp(p + 1, "registered"))
+    if ((QString::fromUtf8(jid)).find("@")==-1)
         return true;
     return false;
 }
@@ -2543,6 +2639,7 @@ void JabberClient::auth_request(const char *jid, unsigned type, const char *text
         case MessageAuthGranted:{
                 if (data == NULL)
                     data = findContact(jid, NULL, true, contact, resource);
+                data->Subscribe.value |= SUBSCRIBE_TO;
                 Event e(EventContactChanged, contact);
                 e.process();
                 return;
@@ -2565,7 +2662,7 @@ void JabberClient::auth_request(const char *jid, unsigned type, const char *text
     }
     //FIXME: In EventMessageReceived handler from filter plugin, there is conditional delete(msg)
     //that causes crash when filter plugin configured to block Authorisation messages.
-    //So parameter must be pointer to object from heap, but then I don't know how it can be safely 
+    //So parameter must be pointer to object from heap, but then I don't know how it can be safely
     //feed if it wasn't in EventMessageReceived. serzh.
     //12.june.2006 zowers: FIXED.
     JabberAuthMessage *msg = new JabberAuthMessage(tempAuthMessages, type);
@@ -2580,6 +2677,16 @@ void JabberClient::auth_request(const char *jid, unsigned type, const char *text
     {
         delete msg;
     }
+    if (type == MessageAuthGranted) {
+        data->Subscribe.value |= SUBSCRIBE_TO;
+        Event e(EventContactChanged, contact);
+        e.process();
+    } else
+    if (type == MessageAuthRefused) {
+        data->Subscribe.value &= ~SUBSCRIBE_TO;
+        Event e(EventContactChanged, contact);
+        e.process();
+    }
 }
 
 void JabberClient::setInvisible(bool bState)
@@ -2822,8 +2929,7 @@ void JabberFileTransfer::write_ready()
         m_socket->close();
         return;
     }
-    time_t now;
-    time(&now);
+    time_t now = time(NULL);
     if ((unsigned)now != m_sendTime){
         m_sendTime = now;
         m_sendSize = 0;
