@@ -196,8 +196,7 @@ void MSNClient::setStatus(unsigned status)
 {
     if (status  == m_status)
         return;
-    time_t now;
-    time(&now);
+    time_t now = time(NULL);
     if (m_status == STATUS_OFFLINE)
         data.owner.OnlineTime.value = now;
     data.owner.StatusTime.value = now;
@@ -209,8 +208,6 @@ void MSNClient::setStatus(unsigned status)
         if (m_status != STATUS_OFFLINE){
             m_status = status;
             data.owner.Status.value = status;
-            time_t now;
-            time(&now);
             data.owner.StatusTime.value = now;
             MSNPacket *packet = new OutPacket(this);
             packet->send();
@@ -249,8 +246,6 @@ void MSNClient::disconnected()
     stop();
     Contact *contact;
     ContactList::ContactIterator it;
-    time_t now;
-    time(&now);
     while ((contact = ++it) != NULL){
         bool bChanged = false;
         MSNUserData *data;
@@ -258,7 +253,7 @@ void MSNClient::disconnected()
         while ((data = (MSNUserData*)(++it)) != NULL){
             if (data->Status.value != STATUS_OFFLINE){
                 data->Status.value = STATUS_OFFLINE;
-                data->StatusTime.value = now;
+                data->StatusTime.value = time(NULL);
                 if (data->sb.ptr){
                     delete (SBSocket*)(data->sb.ptr);
                     data->sb.ptr = NULL;
@@ -583,8 +578,7 @@ void MSNClient::getLine(const char *line)
         Contact *contact;
         MSNUserData *data = findContact(getToken(l, ' ').utf8(), contact);
         if (data && (data->Status.value != status)){
-            time_t now;
-            time(&now);
+            time_t now = time(NULL);
             data->Status.value = status;
             if (data->Status.value == STATUS_OFFLINE){
                 data->OnlineTime.value = now;
@@ -607,8 +601,7 @@ void MSNClient::getLine(const char *line)
         Contact *contact;
         MSNUserData *data = findContact(getToken(l, ' ').utf8(), contact);
         if (data && (data->Status.value != status)){
-            time_t now;
-            time(&now);
+            time_t now = time(NULL);
             if (data->Status.value == STATUS_OFFLINE){
                 data->OnlineTime.value = now;
                 set_ip(&data->IP, 0);
@@ -634,8 +627,7 @@ void MSNClient::getLine(const char *line)
         Contact *contact;
         MSNUserData *data = findContact(getToken(l, ' ').utf8(), contact);
         if (data && (data->Status.value != STATUS_OFFLINE)){
-            time_t now;
-            time(&now);
+            time_t now = time(NULL);
             data->StatusTime.value = now;
             data->Status.value = STATUS_OFFLINE;
             StatusMessage m;
@@ -831,9 +823,7 @@ void MSNClient::authOk()
 {
     m_state    = None;
     m_authChallenge = "";
-    time_t now;
-    time(&now);
-    m_pingTime = now;
+    m_pingTime = time(NULL);
     QTimer::singleShot(TYPING_TIME * 1000, this, SLOT(ping()));
     setPreviousPassword(NULL);
     MSNPacket *packet = new SynPacket(this);
@@ -844,8 +834,7 @@ void MSNClient::ping()
 {
     if (getState() != Connected)
         return;
-    time_t now;
-    time(&now);
+    time_t now = time(NULL);
     if ((unsigned)now >= m_pingTime + PING_TIMEOUT){
         sendLine("PNG");
         m_pingTime = now;
@@ -2249,10 +2238,8 @@ void SBSocket::messageReady()
     }
     if (content_type == "text/x-msmsgscontrol"){
         if (QString(typing.c_str()).lower() == QString(m_data->EMail.ptr).lower()){
-            time_t now;
-            time(&now);
             bool bEvent = (m_data->typing_time.value == 0);
-            m_data->typing_time.value = now;
+            m_data->typing_time.value = time(NULL);
             if (bEvent){
                 Event e(EventContactStatus, m_contact);
                 e.process();
@@ -2971,8 +2958,7 @@ void MSNFileTransfer::write_ready()
         m_state = WaitBye;
         return;
     }
-    time_t now;
-    time(&now);
+    time_t now = time(NULL);
     if ((unsigned)now != m_sendTime){
         m_sendTime = now;
         m_sendSize = 0;
