@@ -167,7 +167,8 @@ OSDPlugin::~OSDPlugin()
     if (m_osd)
         delete m_osd;
     osdPlugin = NULL;
-    Event e(EventRemovePreferences, (void*)user_data_id);
+    unsigned long id = user_data_id + 1;
+    Event(EventRemovePreferences, (void*)id).process();
     getContacts()->unregisterUserData(user_data_id);
 }
 
@@ -723,28 +724,6 @@ void *OSDPlugin::processEvent(Event *e)
     return NULL;
 }
 
-#ifdef WIN32
-#include <windows.h>
-
-/**
- * DLL's entry point
- **/
-int WINAPI DllMain(HINSTANCE, DWORD, LPVOID)
-{
-    return TRUE;
-}
-
-/**
- * This is to prevent the CRT from loading, thus making this a smaller
- * and faster dll.
- **/
-extern "C" BOOL __stdcall _DllMainCRTStartup( HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
-    return DllMain( hinstDLL, fdwReason, lpvReserved );
-}
-
-#endif
-
 #ifndef _MSC_VER
 #include "osd.moc"
 #endif
-
