@@ -1316,25 +1316,3 @@ QWidget *ProxyPlugin::createConfigWindow(QWidget *parent)
 }
 
 const DataDef *ProxyPlugin::proxyData = _proxyData;
-
-#ifdef WIN32
-
-/**
- * DLL's entry point
- **/
-int WINAPI DllMain(HINSTANCE, DWORD, LPVOID)
-{
-    return TRUE;
-}
-
-/**
- * This is to prevent the CRT from loading, thus making this a smaller
- * and faster dll.
- **/
-extern "C" BOOL __stdcall _DllMainCRTStartup( HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
-    return DllMain( hinstDLL, fdwReason, lpvReserved );
-}
-
-#endif
-
-
