@@ -752,9 +752,7 @@ bool RemotePlugin::command(const QString &in, QString &out, bool &bError)
             if (core->getManualStatus() == status)
                 return true;
             core->data.ManualStatus.value  = status;
-            time_t now;
-            time(&now);
-            core->data.StatusTime.value = now;
+            core->data.StatusTime.value = time(NULL);
             Event e(EventClientStatus);
             e.process();
             return true;
@@ -1049,29 +1047,6 @@ void ControlSocket::packet_ready()
     write(CRLF);
 }
 
-#ifdef WIN32
-
-#include <windows.h>
-
-/**
- * DLL's entry point
- **/
-int WINAPI DllMain(HINSTANCE, DWORD, LPVOID)
-{
-    return TRUE;
-}
-
-/**
- * This is to prevent the CRT from loading, thus making this a smaller
- * and faster dll.
- **/
-extern "C" BOOL __stdcall _DllMainCRTStartup( HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
-    return DllMain( hinstDLL, fdwReason, lpvReserved );
-}
-
-#endif
-
 #ifndef _MSC_VER
 #include "remote.moc"
 #endif
-
