@@ -81,7 +81,7 @@ static CommandDef yahoo_descr =
         I18N_NOOP("Yahoo!"),
         "Yahoo!_online",
         "Yahoo!_invisible",
-        I18N_NOOP("http://edit.yahoo.com/config/eval_forgot_pw?.src=pg&.done=http://messenger.yahoo.com/&.redir_from=MESSENGER"),
+        "http://edit.yahoo.com/config/eval_forgot_pw?.src=pg&.done=http://messenger.yahoo.com/&.redir_from=MESSENGER",
         0,
         0,
         0,
@@ -195,27 +195,3 @@ const CommandDef *YahooProtocol::statusList()
 {
     return yahoo_status_list;
 }
-
-#ifdef WIN32
-#include <windows.h>
-
-/**
- * DLL's entry point
- **/
-int WINAPI DllMain(HINSTANCE, DWORD, LPVOID)
-{
-    return TRUE;
-}
-
-/**
- * This is to prevent the CRT from loading, thus making this a smaller
- * and faster dll.
- **/
-extern "C" BOOL __stdcall _DllMainCRTStartup( HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
-    return DllMain( hinstDLL, fdwReason, lpvReserved );
-}
-
-#endif
-
-
-
